@@ -1,7 +1,9 @@
 # -*- coding: utf-8 -*-
 
 """
-0.0.41: optmize network.socket 
+0.1.0: optimize utils
+
+0.0.41: optimize network.socket 
 
 0.0.40: move socket server and bluetooth into network, remove _globals
 
@@ -29,10 +31,10 @@ without change main.py file.
 0.0.6: add common flask functions
 """
 
-__version__ = "0.0.41"
+__version__ = "0.1.0"
 __author__ = "BriFuture"
 
-from .utils import createLogger, initGetText
+from .utils import createLogger, initGetText, setup_logger
 from ._constants import BFF_ROOT_PATH, BFF_OTHER_PATH, terminal_colors
 
 
