@@ -11,13 +11,11 @@ TODO: simplify the plugin loader
 
 Author: BriFuture
 
-Modified: 2020/05/16 20:14
+Modified: 2021/10/21 20:14
 """
 
-
-from .utils import initGetText
-from ._globals import _logger as logger
-
+from .utils import initGetText, createLogger
+logger = createLogger('bffacilities', stream=True)
 tr = initGetText('bffacilities')
 
 class Events(dict):
@@ -76,6 +74,7 @@ class BackTask(object):
                 count = 0
             time.sleep( 1 )
         """
+
 from pathlib import Path
 import os
 import sys
