@@ -65,6 +65,10 @@ class TcpSocketServer(EventHandler, BaseServer):
     Args:
         ip address
         port
+
+    Callback:
+        clientAdded(SocketClient)
+        clientRemoved(SocketClient)
     """
     ClientClass = SocketClient
     def __init__(self, ip, port, maxconn = 500):
