@@ -1,5 +1,5 @@
 import unittest
-from bffacilities.socketserver import TcpSocketServer, SocketClient, logger
+from bffacilities.network import TcpSocketServer, SocketClient, logger
 from bffacilities.utils import changeLoggerLevel
 import logging
 changeLoggerLevel(logger, logging.DEBUG)
